=================
RobotGPT LLM
=================

    robotgpt-interpreter

=================
Quick Install
=================

    `pip install robotgpt-interpreter`

=================
使用样例
=================
$interpreter --api_base "https://dataai.harix.iamidata.com/llm/api/ask" --api_key "your token" --model "openai/gpt-4"